# New in 0.10.0 (2021-04-20)

## Changes

-   PeakVI minor enhancements to differential accessibility and fix scArches support ([#1019])
-   Add DestVI to the codebase ([#1011])
-   Versioned tutorial links ([#1005])
-   Remove old VAEC ([#1006])
-   Use `.numpy()` to convert torch tensors to numpy ndarrays ([#1016])
-   Support backed AnnData ([#1017]), just load anndata with `scvi.data.read_h5ad(path, backed='r+')`
-   Solo interface enhancements ([#1009])
-   Updated README ([#1028])
-   Use Python warnings instead of logger warnings ([#1021])
-   Change totalVI protein background default to `False` is fewer than 10 proteins used ([#1034])

## Bug fixes

-   Fix `SaveBestState` warning ([#1024])
-   New default SCANVI max epochs if loaded with pretrained SCVI model ([#1025]), restores old `<v0.9` behavior.
-   Fix marginal log likelihood computation, which was only being computed on final minibatch of a dataloader. This bug was introduced in the `0.9.X` versions ([#1033]).
-   Fix bug where extra categoricals were not properly extended in `transfer_anndata_setup` ([#1030]).

## Contributors

-   [@adamgayoso]
-   [@romain-lopez]
-   [@talashuach]
-   [@mjayasur]
-   [@wukathy]
-   [@PierreBoyeau]
-   [@morris-frank]

[#1005]: https://github.com/YosefLab/scvi-tools/pull/1005
[#1006]: https://github.com/YosefLab/scvi-tools/pull/1006
[#1009]: https://github.com/YosefLab/scvi-tools/pull/1009
[#1011]: https://github.com/YosefLab/scvi-tools/pull/1011
[#1016]: https://github.com/YosefLab/scvi-tools/pull/1016
[#1017]: https://github.com/YosefLab/scvi-tools/pull/1017
[#1019]: https://github.com/YosefLab/scvi-tools/pull/1019
[#1021]: https://github.com/YosefLab/scvi-tools/pull/1021
[#1024]: https://github.com/YosefLab/scvi-tools/pull/1025
[#1025]: https://github.com/YosefLab/scvi-tools/pull/1025
[#1028]: https://github.com/YosefLab/scvi-tools/pull/1028
[#1030]: https://github.com/YosefLab/scvi-tools/pull/1033
[#1033]: https://github.com/YosefLab/scvi-tools/pull/1033
[#1034]: https://github.com/YosefLab/scvi-tools/pull/1034
[@adamgayoso]: https://github.com/adamgayoso
[@mjayasur]: https://github.com/mjayasur
[@morris-frank]: https://github.com/morris-frank
[@pierreboyeau]: https://github.com/PierreBoyeau
[@romain-lopez]: https://github.com/romain-lopez
[@talashuach]: https://github.com/talashuach
[@wukathy]: https://github.com/wukathy
